@@ -2,12 +2,15 @@
 # pyright: reportPrivateUsage=false
 """Artifact file handling for Hypha."""
 
+import contextlib
 import io
-from typing import TYPE_CHECKING, Self
 from types import TracebackType
+from typing import TYPE_CHECKING, Self
+
 import httpx
-from .sync_utils import run_sync
+
 from .async_artifact_file import AsyncArtifactHttpFile
+from .sync_utils import run_sync
 
 if not TYPE_CHECKING:
     try:
@@ -15,7 +18,7 @@ if not TYPE_CHECKING:
         from pyodide.ffi import run_sync
     except ImportError:
         # Fallback to the default implementation if pyodide is not available
-        pass
+        contextlib.suppress(ImportError)
 
 
 class ArtifactHttpFile(io.IOBase):
@@ -36,6 +39,20 @@ class ArtifactHttpFile(io.IOBase):
         newline: str | None = None,
         name: str | None = None,
     ) -> None:
+        """Initialize an ArtifactHttpFile instance.
+
+        Args:
+            self (Self): The instance itself.
+            url (str): The URL of the artifact file.
+            mode (str, optional): The mode in which to open the file. Defaults to "r".
+            encoding (str | None, optional): The encoding to use for the file.
+                Defaults to None.
+            newline (str | None, optional): The newline character to use for the file.
+                Defaults to None.
+            name (str | None, optional): The name of the file. Defaults to None.
+
+        """
+
         async def get_url() -> str:
             """Get the URL for the artifact file."""
             return url
@@ -49,7 +66,7 @@ class ArtifactHttpFile(io.IOBase):
         )
 
     def __enter__(self: Self) -> Self:
-        """Enter context manager"""
+        """Enter context manager."""
         run_sync(self._async_file.__aenter__())
 
         return self
@@ -60,22 +77,23 @@ class ArtifactHttpFile(io.IOBase):
         exc_val: BaseException | None,
         exc_tb: TracebackType | None,
     ) -> None:
-        """Exit context manager"""
+        """Exit context manager."""
         run_sync(self._async_file.__aexit__(exc_type, exc_val, exc_tb))
 
-    def _download_content(self: Self, range_header: str | None = None) -> None:
+    def download_content(self: Self, range_header: str | None = None) -> None:
         """Download content from URL into buffer, optionally using a range header."""
-        run_sync(self._async_file._download_content(range_header))
+        run_sync(self._async_file.download_content(range_header))
 
-    def _upload_content(self: Self) -> httpx.Response:
-        return run_sync(self._async_file._upload_content())
+    def upload_content(self: Self) -> httpx.Response:
+        """Upload content from buffer to the remote URL."""
+        return run_sync(self._async_file.upload_content())
 
     def tell(self: Self) -> int:
-        """Return current position in the file"""
-        return self._async_file._pos
+        """Return current position in the file."""
+        return self._async_file.tell()
 
     def seek(self: Self, offset: int, whence: int = 0) -> int:
-        """Change stream position"""
+        """Change stream position."""
         return self._async_file.seek(offset, whence)
 
     def read(self: Self, size: int = -1) -> bytes | str:
@@ -83,26 +101,26 @@ class ArtifactHttpFile(io.IOBase):
         return run_sync(self._async_file.read(size))
 
     def write(self: Self, data: str | bytes) -> int:
-        """Write data to the file"""
+        """Write data to the file."""
         return run_sync(self._async_file.write(data))
 
     def readable(self: Self) -> bool:
-        """Return whether the file is readable"""
+        """Return whether the file is readable."""
         return self._async_file.readable()
 
     def writable(self: Self) -> bool:
-        """Return whether the file is writable"""
+        """Return whether the file is writable."""
         return self._async_file.writable()
 
     def seekable(self: Self) -> bool:
-        """Return whether the file is seekable"""
+        """Return whether the file is seekable."""
         return self._async_file.seekable()
 
     def close(self: Self) -> None:
-        """Close the file and upload content if in write mode"""
+        """Close the file and upload content if in write mode."""
         run_sync(self._async_file.close())
 
     @property
     def closed(self: Self) -> bool:
-        """Return whether the file is closed"""
+        """Return whether the file is closed."""
         return self._async_file.closed
