@@ -1,23 +1,32 @@
-"""
-Integration tests for the HyphaArtifact module.
+"""Integration tests for the HyphaArtifact module.
 
 This module contains integration tests for the HyphaArtifact class,
 testing real file operations such as creation, reading, copying, and deletion
 against an actual Hypha artifact service.
 """
 
+import logging
+import os
+import tempfile
 from pathlib import Path
 from typing import Any
+
 import pytest
-from conftest import ArtifactTestMixin
+
 from hypha_artifact import HyphaArtifact
+from tests.conftest import ArtifactTestMixin
 
 
 @pytest.fixture(scope="module", name="artifact")
 def get_artifact(artifact_name: str, artifact_setup_teardown: tuple[str, str]) -> Any:
     """Create a test artifact with a real connection to Hypha."""
     token, workspace = artifact_setup_teardown
-    return HyphaArtifact(artifact_name, workspace, token, server_url="https://hypha.aicell.io")
+    return HyphaArtifact(
+        artifact_name,
+        workspace,
+        token,
+        server_url="https://hypha.aicell.io",
+    )
 
 
 class TestHyphaArtifactIntegration(ArtifactTestMixin):
@@ -34,7 +43,7 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
         artifact.commit()
 
         # Verify the file was created
-        files = artifact.ls("/")
+        files = artifact.ls("/", detail=True)
         file_names = [f["name"] for f in files]
         assert (
             test_file_path in file_names
@@ -43,7 +52,7 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
     def test_list_files(self, artifact: HyphaArtifact) -> None:
         """Test listing files in the artifact using real operations."""
         # First, list files with detail=True (default)
-        files = artifact.ls("/")
+        files = artifact.ls("/", detail=True)
         self._validate_file_listing(files)
 
         # Test listing with detail=False
@@ -51,7 +60,9 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
         self._validate_file_listing(file_names)
 
     def test_read_file_content(
-        self, artifact: HyphaArtifact, test_content: str
+        self,
+        artifact: HyphaArtifact,
+        test_content: str,
     ) -> None:
         """Test reading content from a file in the artifact using real operations."""
         test_file_path = "test_file.txt"
@@ -80,7 +91,7 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
             artifact.commit()
 
         assert artifact.exists(
-            source_path
+            source_path,
         ), f"Source file {source_path} should exist before copying"
 
         # Copy the file
@@ -149,7 +160,7 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
         artifact.copy(original_file, copied_file)
         artifact.commit()
         assert artifact.exists(copied_file)
-        print(artifact.ls("/"))
+        logging.info(artifact.ls("/", detail=True))
 
         # Step 4: Remove copied file
         artifact.edit(stage=True)
@@ -159,7 +170,9 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
         assert artifact.exists(original_file)
 
     def test_partial_file_read(
-        self, artifact: HyphaArtifact, test_content: str
+        self,
+        artifact: HyphaArtifact,
+        test_content: str,
     ) -> None:
         """Test reading only part of a file using the size parameter in read."""
         test_file_path = "partial_read_test.txt"
@@ -179,10 +192,12 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
         self._validate_file_content(partial_content, expected_content)
 
     def test_get_file(
-        self, artifact: HyphaArtifact, test_content: str, tmp_path: Path
+        self,
+        artifact: HyphaArtifact,
+        test_content: str,
+        tmp_path: Path,
     ) -> None:
         """Test copying a file from remote (artifact) to local filesystem."""
-
         remote_file = "sync_get_test_file.txt"
         local_file = tmp_path / "local_get_test_file.txt"
 
@@ -197,15 +212,17 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
 
         # Verify local file exists and has correct content
         assert local_file.exists(), f"Local file {local_file} should exist"
-        with open(local_file, "r", encoding="utf-8") as f:
+        with open(local_file, encoding="utf-8") as f:
             local_content = f.read()
         self._validate_file_content(local_content, test_content)
 
     def test_put_file(
-        self, artifact: HyphaArtifact, test_content: str, tmp_path: Path
+        self,
+        artifact: HyphaArtifact,
+        test_content: str,
+        tmp_path: Path,
     ) -> None:
         """Test copying a file from local filesystem to remote (artifact)."""
-
         local_file = tmp_path / "local_put_test_file.txt"
         remote_file = "sync_put_test_file.txt"
 
@@ -224,10 +241,12 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
         self._validate_file_content(remote_content, test_content)
 
     def test_get_directory_recursive(
-        self, artifact: HyphaArtifact, test_content: str, tmp_path: Path
+        self,
+        artifact: HyphaArtifact,
+        test_content: str,
+        tmp_path: Path,
     ) -> None:
         """Test copying a directory recursively from remote to local."""
-
         remote_dir = "sync_get_dir"
         remote_file1 = f"{remote_dir}/file1.txt"
         remote_file2 = f"{remote_dir}/subdir/file2.txt"
@@ -251,19 +270,21 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
         assert local_file1.exists(), f"Local file {local_file1} should exist"
         assert local_file2.exists(), f"Local file {local_file2} should exist"
 
-        with open(local_file1, "r", encoding="utf-8") as f:
+        with open(local_file1, encoding="utf-8") as f:
             content1 = f.read()
-        with open(local_file2, "r", encoding="utf-8") as f:
+        with open(local_file2, encoding="utf-8") as f:
             content2 = f.read()
 
         self._validate_file_content(content1, test_content + "_1")
         self._validate_file_content(content2, test_content + "_2")
 
     def test_put_directory_recursive(
-        self, artifact: HyphaArtifact, test_content: str, tmp_path: Path
+        self,
+        artifact: HyphaArtifact,
+        test_content: str,
+        tmp_path: Path,
     ) -> None:
         """Test copying a directory recursively from local to remote."""
-
         local_dir = tmp_path / "local_put_dir"
         local_subdir = local_dir / "subdir"
         local_file1 = local_dir / "file1.txt"
@@ -296,11 +317,12 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
         self._validate_file_content(content2, test_content + "_2")
 
     def test_get_multiple_files(
-        self, artifact: HyphaArtifact, test_content: str, tmp_path: Path
+        self,
+        artifact: HyphaArtifact,
+        test_content: str,
+        tmp_path: Path,
     ) -> None:
         """Test copying multiple files from remote to local using lists."""
-        import os
-
         remote_files = ["sync_get_multi1.txt", "sync_get_multi2.txt"]
         local_files = [
             str(tmp_path / "local_get_multi1.txt"),
@@ -320,15 +342,17 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
         # Verify local files exist and have correct content
         for i, local_file in enumerate(local_files):
             assert os.path.exists(local_file), f"Local file {local_file} should exist"
-            with open(local_file, "r", encoding="utf-8") as f:
+            with open(local_file, encoding="utf-8") as f:
                 content = f.read()
             self._validate_file_content(content, test_content + f"_{i+1}")
 
     def test_put_multiple_files(
-        self, artifact: HyphaArtifact, test_content: str, tmp_path: Path
+        self,
+        artifact: HyphaArtifact,
+        test_content: str,
+        tmp_path: Path,
     ) -> None:
         """Test copying multiple files from local to remote using lists."""
-
         local_files = [
             str(tmp_path / "local_put_multi1.txt"),
             str(tmp_path / "local_put_multi2.txt"),
@@ -348,7 +372,107 @@ class TestHyphaArtifactIntegration(ArtifactTestMixin):
         # Verify remote files exist and have correct content
         for i, remote_file in enumerate(remote_files):
             assert artifact.exists(
-                remote_file
+                remote_file,
             ), f"Remote file {remote_file} should exist"
             content = artifact.cat(remote_file)
             self._validate_file_content(content, test_content + f"_{i+1}")
+
+    def test_multipart_upload_large_file(self, artifact: HyphaArtifact) -> None:
+        """Test multipart upload with a large file."""
+        multipart_config: dict[str, bool | int] = {
+            "enable": True,
+            "threshold": 1024,  # 1MB threshold
+            "chunk_size": 10 * 1024 * 1024,  # 10MB chunks
+        }
+
+        # Create a temporary large file (20MB to test multipart)
+        file_size = 20 * 1024 * 1024  # 20MB total
+
+        with tempfile.NamedTemporaryFile(delete=False) as temp_file:
+            # Write test data in chunks
+            test_data = b"A" * 1024  # 1KB of 'A's
+            for _ in range(file_size // len(test_data)):
+                temp_file.write(test_data)
+            temp_file_path = temp_file.name
+
+        try:
+            remote_path = "large_multipart_test.bin"
+
+            # Upload using multipart
+            artifact.edit(stage=True)
+            artifact.put(
+                temp_file_path,
+                remote_path,
+                multipart_config=multipart_config,
+            )
+            artifact.commit()
+
+            # Verify the file exists
+            assert artifact.exists(
+                remote_path,
+            ), f"Uploaded file {remote_path} should exist"
+
+            # Verify file size matches
+            info = artifact.info(remote_path)
+            assert (
+                info.get("size") == file_size
+            ), f"File size should be {file_size} bytes"
+
+            # Clean up remote file
+            artifact.edit(stage=True)
+            artifact.rm(remote_path)
+            artifact.commit()
+        except Exception as e:
+            raise e
+        finally:
+            # Clean up local temp file
+            os.unlink(temp_file_path)
+
+    def test_upload_folder(self, artifact: HyphaArtifact) -> None:
+        """Test uploading a folder with multiple files."""
+        # Create a temporary folder structure
+        with tempfile.TemporaryDirectory() as temp_dir:
+            temp_path = Path(temp_dir)
+
+            # Create test files
+            (temp_path / "file1.txt").write_text("Content of file 1")
+            (temp_path / "file2.txt").write_text("Content of file 2")
+
+            # Create subdirectory
+            subdir = temp_path / "subdir"
+            subdir.mkdir()
+            (subdir / "file3.txt").write_text("Content of file 3")
+
+            # Upload folder
+            remote_folder = "test_folder_upload"
+            artifact.edit(stage=True)
+            artifact.put(
+                str(temp_path),
+                remote_folder,
+                recursive=True,
+            )
+            artifact.commit()
+
+            # Verify files were uploaded
+            files = artifact.ls(remote_folder)
+            expected_files = {"file1.txt", "file2.txt", "subdir"}
+            actual_files = set(files)
+
+            assert expected_files.issubset(
+                actual_files,
+            ), f"Expected files {expected_files} not found in {actual_files}"
+
+            # Verify subdirectory file
+            subdir_files = artifact.ls(f"{remote_folder}/subdir")
+            assert "file3.txt" in subdir_files, "Subdirectory file should be uploaded"
+
+            # Verify file contents
+            content1 = artifact.cat(f"{remote_folder}/file1.txt")
+            assert content1 == "Content of file 1", "File content should match"
+
+            # Clean up
+            artifact.edit(stage=True)
+            artifact.rm(f"{remote_folder}/file1.txt")
+            artifact.rm(f"{remote_folder}/file2.txt")
+            artifact.rm(f"{remote_folder}/subdir/file3.txt")
+            artifact.commit()
